gleeps_dev_tools/state_list

Types

pub type Data {
  Data(rows: List(StateInfo))
}

Constructors

pub type FromHeaderError {
  NonIntCount
  NonIntStartingAt
}

Constructors

  • NonIntCount
  • NonIntStartingAt
pub type Limit {
  NoLimit
  Latest(count: Int)
  WithinRange(starting_at: Int, count: Int)
}

Constructors

  • NoLimit
  • Latest(count: Int)
  • WithinRange(starting_at: Int, count: Int)
pub type StateInfo {
  StateInfo(
    version: Int,
    byte_size: Int,
    last_write: timestamp.Timestamp,
  )
}

Constructors

Values

pub fn decoder() -> decode.Decoder(Data)
pub const default_limit: Limit
pub fn describe_limit(limit: Limit) -> String

Turn Limit into a human readable string

pub fn limit_from_headers(
  request: request.Request(a),
) -> Result(Limit, FromHeaderError)

Try to get the limit from the request headers

pub fn set_limit_headers(
  request: request.Request(String),
  limit: Limit,
) -> request.Request(String)

Add the supplied limit to the supplied request as headers

pub fn to_json(data: Data) -> json.Json
Search Document